@@ -1,6 +1,6 @@
-package Pcore::Captcha v0.1.4;
+package Pcore::Captcha v0.2.0;
 
-use Pcore -class;
+use Pcore -dist, -class;
 
 has cb         => ( is => 'ro', isa => CodeRef,           required => 1 );
 has captcha    => ( is => 'ro', isa => ScalarRef,         required => 1 );
